@@ -7,20 +7,20 @@ use MongoDB;
 
 with 'Catmandu::Store';
 
+our $VERSION = '0.04';
+
 =head1 NAME
 
 Catmandu::Store::MongoDB - A searchable store backed by MongoDB
 
-=head1 VERSION
-
-Version 0.0302
-
-=cut
-
-our $VERSION = '0.0303';
-
 =head1 SYNOPSIS
 
+    # On the command line
+    $ catmandu import -v JSON --multiline 1 to MongoDB --database_name bibliography --bag books < books.json
+    $ catmandu export MongoDB --database_name bibliography --bag books to YAML
+    $ catmandu count MongoDB --database_name bibliography --bag books --query '{"PublicationYear": "1937"}'
+
+    # In perl
     use Catmandu::Store::MongoDB;
 
     my $store = Catmandu::Store::MongoDB->new(database_name => 'test');
@@ -52,95 +52,92 @@ our $VERSION = '0.0303';
 
     my $iterator = $store->bag->searcher(query => {name => "Patrick"});
 
-
-
 =head1 DESCRIPTION
 
 A Catmandu::Store::MongoDB is a Perl package that can store data into
-MongoDB databases. The database as a whole is called a 'store'.
+L<MongoDB> databases. The database as a whole is called a 'store'.
 Databases also have compartments (e.g. tables) called Catmandu::Bag-s.
 
+=head1 DEPRECATION NOTICE
+
+The following connection parameters are depreacted and will be removed in a future version of this module:
+    
+    - connect_retry
+    - connect_retry_sleep
+
 =head1 METHODS
 
 =head2 new(database_name => $name , %opts )
 
-Create a new Catmandu::Store::MongoDB store with name $name. Optionally provide
-connection parameters (see MongoDB::MongoClient for possible options).
-
-This module support to additional connection parameters:
-    
-    - connect_retry => NUM : connection's should be retried NUM times for success
-    - connect_retry_sleep => NUM : sleep NUM seconds after any connection failure
+Create a new Catmandu::Store::MongoDB store with name $name. Optionally 
+provide connection parameters (see L<MongoDB::MongoClient> for possible 
+options).
 
 =head2 bag($name)
 
-Create or retieve a bag with name $name. Returns a Catmandu::Bag.
+Create or retieve a bag with name $name. Returns a L<Catmandu::Bag>.
 
 =head2 client
 
-Return the MongoDB::MongoClient instance.
+Return the L<MongoDB::MongoClient> instance.
 
 =head2 database
 
-Return a MongoDB::Database instance.
+Return a L<MongoDB::Database> instance.
 
 =cut
 
-my $CLIENT_ARGS = [qw(
-    host
-    w
-    wtimeout
-    j
-    auto_reconnect
-    auto_connect
-    timeout
-    username
-    password
-    db_name
-    query_timeout
-    max_bson_size
-    find_master
-    ssl
-    dt_type
-    inflate_dbrefs
-)];
+my $CLIENT_ARGS = [
+    qw(
+        connect_timeout_ms
+        db_name
+        dt_type
+        find_master
+        host
+        j
+        password
+        socket_timeout_ms
+        ssl
+        username
+        w
+        wtimeout
+        )
+];
 
-has connect_retry        => (is => 'ro', default => sub { 0 } );
-has connect_retry_sleep  => (is => 'ro', default => sub { 1 } );
+# deprecated. remove this attribute in a future version
+has connect_retry => ( is => 'ro' );
+# deprecated. remove this attribute in a future version
+has connect_retry_sleep => ( is => 'ro' );
 has client        => (is => 'ro', lazy => 1, builder => '_build_client');
 has database_name => (is => 'ro', required => 1);
 has database      => (is => 'ro', lazy => 1, builder => '_build_database');
 
 sub _build_client {
-    my $self  = shift;
-    my $retry = $self->connect_retry;
-    my $args  = delete $self->{_args};
-    my $host  = $self->{_args}->{host} // 'mongodb://localhost:27017';
-
-    do {
-        $self->log->debug("Connecting to $host");
-        my $client = eval { MongoDB::MongoClient->new($args) };
-        if ($@) {
-            die $@ unless $self->connect_retry;
-            $self->log->info("Can't connect to $host. Sleeping : " .
-                             $self->connect_retry_sleep .
-                             " seconds ($retry retries left)");
-            sleep $self->connect_retry_sleep;
-        }
-        else {
-           return $client;
-        }
-    } while (--$retry > 0);
-
-    Catmandu::Error->throw("Can't connect to $host");
+    my $self = shift;
+    my $args = delete $self->{_args};
+    my $host = $self->{_args}->{host} // 'mongodb://localhost:27017';
+    $self->log->debug("Build MongoClient for $host");
+    my $client = MongoDB::MongoClient->new($args);
+    return $client;
 }
 
 sub _build_database {
-    my $self = $_[0]; $self->client->get_database($self->database_name);
+    my $self          = shift;
+    my $database_name = $self->database_name;
+    $self->log->debug("Build or get database $database_name");
+    my $database = $self->client->get_database($database_name);
+    return $database;
 }
 
 sub BUILD {
     my ($self, $args) = @_;
+
+    if ( $self->{connect_retry} || $self->{connect_retry_sleep} ) {
+        warnings::warnif( "deprecated",
+            "Connection parameter \'connect_retry\' and \'connect_retry_sleep\' are deprecated and will be removed in future versions of Catmandu::Store::MongoDB"
+        );
+    }
+
     $self->{_args} = {};
     for my $key (@$CLIENT_ARGS) {
         $self->{_args}{$key} = $args->{$key} if exists $args->{$key};
@@ -155,6 +152,10 @@ L<Catmandu::Bag>, L<Catmandu::Searchable> , L<MongoDB::MongoClient>
 
 Nicolas Steenlant, C<< <nicolas.steenlant at ugent.be> >>
 
+=head1 CONTRIBUTORS
+
+Johann Rolschewski, C<< <jorol at cpan.org> >>
+
 =head1 LICENSE AND COPYRIGHT
 
 This program is free software; you can redistribute it and/or modify it
